@@ -18,6 +18,7 @@ common_statements: Dict[str, str] = {
     "CliRunner": "from click.testing import CliRunner",
     "copyfile": "from shutil import copyfile",
     "dedent": "from textwrap import dedent",
+    "Enum": "from enum import Enum",
     "Faker": "from faker import Faker",
     "FrozenDateTimeFactory": "from freezegun.api import FrozenDateTimeFactory",
     "LocalPath": "from py._path.local import LocalPath",
@@ -42,6 +43,7 @@ class SourceCode:  # noqa: R090
         self.imports: List[str] = []
         self.typing: List[str] = []
         self.code: List[str] = []
+        self._trailing_newline = False
         self._split_code(source_code)
 
     def fix(self) -> str:
@@ -75,6 +77,8 @@ class SourceCode:  # noqa: R090
         self._extract_import_statements(source_code_lines)
         self._extract_typing_statements(source_code_lines)
         self._extract_code(source_code_lines)
+        if source_code.endswith("\n"):
+            self._trailing_newline = True
 
     def _extract_header(self, source_lines: List[str]) -> None:
         """Save the module leading comments and docstring from the source code.
@@ -98,8 +102,8 @@ class SourceCode:  # noqa: R090
             elif re.match(r'"{3}.*', line):
                 # Match multiple line docstrings start
                 docstring_type = "start_multiple_lines"
-            elif re.match(r"#.*", line):
-                # Match leading comments
+            elif re.match(r"#.*", line) or line == "":
+                # Match leading comments and empty lines
                 pass
             elif docstring_type in [None, "multiple_lines"]:
                 break
@@ -181,7 +185,13 @@ class SourceCode:  # noqa: R090
         ]
 
         # Add new lines between existent sections
-        return "\n\n".join(sections).strip()
+        source_code = "\n\n".join(sections).strip()
+
+        # Respect the trailing newline
+        if self._trailing_newline:
+            source_code += "\n"
+
+        return source_code
 
     def _move_imports_to_top(self) -> None:
         """Fix python source code to move import statements to the top of the file.
@@ -229,11 +239,14 @@ class SourceCode:  # noqa: R090
     def _fix_flake_import_errors(self) -> None:
         """Fix python source code to correct missed or unused import statements."""
         error_messages = autoflake.check(self._join_code())
+        fixed_packages = []
 
         for message in error_messages:
             if isinstance(message, (UndefinedName, UndefinedExport)):
                 object_name = message.message_args[0]
-                self._add_package(object_name)
+                if object_name not in fixed_packages:
+                    self._add_package(object_name)
+                    fixed_packages.append(object_name)
             elif isinstance(message, UnusedImport):
                 import_name = message.message_args[0]
                 self._remove_unused_imports(import_name)
@@ -345,7 +358,7 @@ class SourceCode:  # noqa: R090
         Returns:
             import_string
         """
-        if name in common_statements.keys():
+        if name in common_statements:
             return common_statements[name]
 
         return None
